Enum bosch_bme680::BmeError
source · pub enum BmeError<I2C>where
I2C: I2c<SevenBitAddress>,{
WriteError(I2C::Error),
WriteReadError(I2C::Error),
UnexpectedChipId(u8),
MeasuringTimeOut,
}Expand description
All possible errors
Variants
WriteError(I2C::Error)
Error during I2C write operation.
WriteReadError(I2C::Error)
Error during I2C WriteRead operation.
UnexpectedChipId(u8)
Got an unexpected ChipId during sensor initalization.
MeasuringTimeOut
After running the measurment the sensor blocks until the ‘new data bit’ of the sensor is set. Should this take more than 5 tries an error is returned instead of incorrect data.