Enum bosch_bme680::Oversampling
source · pub enum Oversampling {
Skipped,
By1,
By2,
By4,
By8,
By16,
}Expand description
Oversampling settings for temperature, humidity, pressure. Skipping means no measurment will be taken, which is not recommended for the temperature as it’s needed to calculate the adjusted values for hummidiy and pressure.
Variants
Implementations