pub enum BmeError<I2C>where
    I2C: WriteRead + Write,
    <I2C as WriteRead>::Error: Debug,
    <I2C as Write>::Error: Debug,
{ WriteError(<I2C as Write>::Error), WriteReadError(<I2C as WriteRead>::Error), UnexpectedChipId(u8), MeasuringTimeOut, }
All possible errors

Variants



WriteError(<I2C as Write>::Error)

Error during I2C write operation.



WriteReadError(<I2C as WriteRead>::Error)

Error during I2C WriteRead operation.



UnexpectedChipId(u8)

Got an unexpected ChipId during sensor initalization.



MeasuringTimeOut

After running the measurment the sensor blocks until the ‘new data bit’ of the sensor is set. Should this take more than 5 tries an error is returned instead of incorrect data.